OiRA

Help

1. Priprema
2. Uključite
3. Prepoznavanje + procjena
4. Plan mjera
5. Završni dokumenti
6. Status 0%

# Preuzmi i ispiši svoje izvješće

Preporučujemo da u tvrtki uvijek bude dostupan ažurirani ispis verzije procjene rizika (izvješće)!

Završni dokumenti

- Format: Rich Text Format (.rtf)
- Contains: all the information and input provided by you throughout the risk assessment process.

Plan mjera

- Format: Office Open XML Workbook (.xlsx)
- Contains: main elements to effectively manage the risks at your workplace.

Pregled rizika

- Format: Portable Document Format (.pdf)
- Contains: an overview of the risks identified

Pregled mjera

- Format: Portable Document Format (.pdf)
- Contains: an overview of the measures to be implemented.

Scroll to top
Back

## report-download.html

Više

Help

Standard search Advanced search

- Splash and Shine Cleaners Last saved 19 days ago based on EU Cleaning More
- Commercial Guardinng, Leicester Last saved 2 months ago based on Private Security EU More
- Private Security, Grafton Street Last saved 2 months ago based on Private Security EU More
- Office operations in times of COVID-19 Last saved 4 months ago based on COVID-19 More